You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@avro.apache.org by "Scott Carey (JIRA)" <ji...@apache.org> on 2011/02/14 02:28:57 UTC
[jira] Created: (AVRO-765) Java: Improvement to BinaryDecoder
readLong performance
Java: Improvement to BinaryDecoder readLong performance
-------------------------------------------------------
Key: AVRO-765
URL: https://issues.apache.org/jira/browse/AVRO-765
Project: Avro
Issue Type: Improvement
Reporter: Scott Carey
Assignee: Scott Carey
Priority: Minor
Fix For: 1.5.0
I have found a few enhancements to the BinaryDecoder while I was working on the BinaryEncoders.
BinaryDecoder's readLong improves by 75%+ on the latest 64bit Sun JVM's.
--
This message is automatically generated by JIRA.
-
For more information on JIRA, see: http://www.atlassian.com/software/jira
[jira] Resolved: (AVRO-765) Java: Improvement to BinaryDecoder
readLong performance
Posted by "Scott Carey (JIRA)" <ji...@apache.org>.
[ https://issues.apache.org/jira/browse/AVRO-765?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]
Scott Carey resolved AVRO-765.
------------------------------
Resolution: Fixed
Committed @ r1070613
> Java: Improvement to BinaryDecoder readLong performance
> -------------------------------------------------------
>
> Key: AVRO-765
> URL: https://issues.apache.org/jira/browse/AVRO-765
> Project: Avro
> Issue Type: Improvement
> Reporter: Scott Carey
> Assignee: Scott Carey
> Priority: Minor
> Fix For: 1.5.0
>
> Attachments: AVRO-765.patch
>
>
> I have found a few enhancements to the BinaryDecoder while I was working on the BinaryEncoders.
> BinaryDecoder's readLong improves by 75%+ on the latest 64bit Sun JVM's.
--
This message is automatically generated by JIRA.
-
For more information on JIRA, see: http://www.atlassian.com/software/jira
[jira] Commented: (AVRO-765) Java: Improvement to BinaryDecoder
readLong performance
Posted by "Doug Cutting (JIRA)" <ji...@apache.org>.
[ https://issues.apache.org/jira/browse/AVRO-765?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=12994390#comment-12994390 ]
Doug Cutting commented on AVRO-765:
-----------------------------------
+1 Looks great to me. Thanks, Scott!
> Java: Improvement to BinaryDecoder readLong performance
> -------------------------------------------------------
>
> Key: AVRO-765
> URL: https://issues.apache.org/jira/browse/AVRO-765
> Project: Avro
> Issue Type: Improvement
> Reporter: Scott Carey
> Assignee: Scott Carey
> Priority: Minor
> Fix For: 1.5.0
>
> Attachments: AVRO-765.patch
>
>
> I have found a few enhancements to the BinaryDecoder while I was working on the BinaryEncoders.
> BinaryDecoder's readLong improves by 75%+ on the latest 64bit Sun JVM's.
--
This message is automatically generated by JIRA.
-
For more information on JIRA, see: http://www.atlassian.com/software/jira
[jira] Updated: (AVRO-765) Java: Improvement to BinaryDecoder
readLong performance
Posted by "Scott Carey (JIRA)" <ji...@apache.org>.
[ https://issues.apache.org/jira/browse/AVRO-765?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]
Scott Carey updated AVRO-765:
-----------------------------
Attachment: AVRO-765.patch
readLong is currently about half the speed of readInt, even if operating on the same small numbers. I was able to reorganize readLong into two methods that the compiler can fully optimize. The JIT favors smaller methods by attempting more optimizations on them.
The current performance is:
{noformat}
test name time M entries/sec M bytes/sec bytes/cycle
IntRead: 761 ms 262.586 661.007 629325
SmallLongRead: 1606 ms 124.481 313.356 629325
LongRead: 2637 ms 75.833 331.346 1092353
{noformat}
The changes in this patch bring up the readLong performance to be close to readInt.
{noformat}
test name time M entries/sec M bytes/sec bytes/cycle
IntRead: 742 ms 269.301 677.911 629325
SmallLongRead: 833 ms 239.884 603.860 629325
LongRead: 1663 ms 120.210 525.247 1092353
{noformat}
> Java: Improvement to BinaryDecoder readLong performance
> -------------------------------------------------------
>
> Key: AVRO-765
> URL: https://issues.apache.org/jira/browse/AVRO-765
> Project: Avro
> Issue Type: Improvement
> Reporter: Scott Carey
> Assignee: Scott Carey
> Priority: Minor
> Fix For: 1.5.0
>
> Attachments: AVRO-765.patch
>
>
> I have found a few enhancements to the BinaryDecoder while I was working on the BinaryEncoders.
> BinaryDecoder's readLong improves by 75%+ on the latest 64bit Sun JVM's.
--
This message is automatically generated by JIRA.
-
For more information on JIRA, see: http://www.atlassian.com/software/jira